# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-06-07 09:05

from __future__ import unicode_literals
from django.db import migrations
from django.contrib.postgres.operations import HStoreExtension

class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
    HStoreExtension(),
    ]
